@@ -46,7 +46,7 @@ static PrefsDisplayItem all_items[] =
 	 STOCK_PIXMAP_MAIL_RECEIVE_ALL,	NULL, FALSE, FALSE},
 	{T_REMOTE_MAILBOX,	"remote-mailbox",	N_("Remote mailbox"),
 	 N_("POP3 Remote mailbox"),
-	 -1, GTK_STOCK_NETWORK, FALSE, FALSE},
+	 STOCK_PIXMAP_REMOTE_MAILBOX, GTK_STOCK_NETWORK, FALSE, FALSE},
 	{T_SEND_QUEUE,	"send-queue",	N_("Send"),
 	 N_("Send queued message(s)"),
 	 STOCK_PIXMAP_MAIL_SEND, NULL, FALSE, FALSE},
@@ -73,31 +73,31 @@ static PrefsDisplayItem all_items[] =
 	 STOCK_PIXMAP_NOTSPAM, NULL, FALSE, FALSE},
 	{T_NEXT,	"next",		N_("Next"),
 	 N_("Next unread message"),
-	 -1, GTK_STOCK_GO_DOWN, FALSE, FALSE},
+	 STOCK_PIXMAP_NEXT, GTK_STOCK_GO_DOWN, FALSE, FALSE},
 	{T_PREV,	"prev",		N_("Prev"),
 	 N_("Previous unread message"),
-	 -1, GTK_STOCK_GO_UP, FALSE, FALSE},
+	 STOCK_PIXMAP_PREV, GTK_STOCK_GO_UP, FALSE, FALSE},
 	{T_SEARCH,	"search",	N_("Search"),
 	 N_("Search messages"),
-	 -1, GTK_STOCK_FIND, FALSE, FALSE},
+	 STOCK_PIXMAP_SEARCH, GTK_STOCK_FIND, FALSE, FALSE},
 	{T_PRINT,	"print",	N_("Print"),
 	 N_("Print message"),
-	 -1, GTK_STOCK_PRINT, FALSE, FALSE},
+	 STOCK_PIXMAP_PRINT, GTK_STOCK_PRINT, FALSE, FALSE},
 	{T_STOP,	"stop",		N_("Stop"),
 	 N_("Stop receiving"),
-	 -1, GTK_STOCK_STOP, FALSE, FALSE},
+	 STOCK_PIXMAP_STOP, GTK_STOCK_STOP, FALSE, FALSE},
 	{T_ADDRESS_BOOK,	"address-book",	N_("Address"),
 	 N_("Address book"),
 	 STOCK_PIXMAP_ADDRESS_BOOK, NULL, FALSE, FALSE},
 	{T_EXECUTE,	"execute",	N_("Execute"),
 	 N_("Execute marked process"),
-	 -1, GTK_STOCK_EXECUTE, FALSE, FALSE},
+	 STOCK_PIXMAP_EXECUTE, GTK_STOCK_EXECUTE, FALSE, FALSE},
 	{T_COMMON_PREFS,	"common-prefs",	N_("Prefs"),
 	 N_("Common preferences"),
-	 -1, GTK_STOCK_PREFERENCES, FALSE, FALSE},
+	 STOCK_PIXMAP_COMMON_PREFS, GTK_STOCK_PREFERENCES, FALSE, FALSE},
 	{T_ACCOUNT_PREFS,	"account-prefs", N_("Account"),
 	 N_("Account preferences"),
-	 -1, GTK_STOCK_PREFERENCES, FALSE, FALSE},
+	 STOCK_PIXMAP_ACCOUNT_PREFS, GTK_STOCK_PREFERENCES, FALSE, FALSE},
 
 	{T_SEND,	"send",		N_("Send"),
 	 N_("Send message"),
@@ -107,7 +107,7 @@ static PrefsDisplayItem all_items[] =
 	 STOCK_PIXMAP_MAIL_SEND_QUEUE, NULL, FALSE, FALSE},
 	{T_DRAFT,	"draft",	N_("Draft"),
 	 N_("Save to draft folder"),
-	 -1, GTK_STOCK_SAVE, FALSE, FALSE},
+	 STOCK_PIXMAP_SAVE, GTK_STOCK_SAVE, FALSE, FALSE},
 	{T_INSERT_FILE,	"insert-file",	N_("Insert"),
 	 N_("Insert file"),
 	 STOCK_PIXMAP_INSERT_FILE, NULL, FALSE, FALSE},
@@ -119,11 +119,7 @@ static PrefsDisplayItem all_items[] =
 	 STOCK_PIXMAP_SIGN, NULL, FALSE, FALSE},
 	{T_EDITOR,	"editor",	N_("Editor"),
 	 N_("Edit with external editor"),
-#ifdef GTK_STOCK_EDIT
-	 -1, GTK_STOCK_EDIT, FALSE, FALSE},
-#else
-	 STOCK_PIXMAP_MAIL_COMPOSE, NULL, FALSE, FALSE},
-#endif
+	 STOCK_PIXMAP_EDIT, GTK_STOCK_EDIT, FALSE, FALSE},
 	{T_LINEWRAP,	"linewrap",	N_("Linewrap"),
 	 N_("Wrap all long lines"),
 	 STOCK_PIXMAP_LINEWRAP, NULL, FALSE, FALSE},
